Index: src/mips/code-stubs-mips.cc |
=================================================================== |
--- src/mips/code-stubs-mips.cc (revision 12500) |
+++ src/mips/code-stubs-mips.cc (working copy) |
@@ -5405,12 +5405,12 @@ |
// Set FixedArray length. |
__ sll(t2, t1, kSmiTagSize); |
__ sw(t2, FieldMemOperand(a3, FixedArray::kLengthOffset)); |
- // Fill contents of fixed-array with the-hole. |
- __ li(a2, Operand(masm->isolate()->factory()->the_hole_value())); |
+ // Fill contents of fixed-array with undefined. |
+ __ LoadRoot(a2, Heap::kUndefinedValueRootIndex); |
__ Addu(a3, a3, Operand(FixedArray::kHeaderSize - kHeapObjectTag)); |
// Fill fixed array elements with hole. |
// v0: JSArray, tagged. |
- // a2: the hole. |
+ // a2: undefined. |
// a3: Start of elements in FixedArray. |
// t1: Number of elements to fill. |
Label loop; |
@@ -5405,12 +5405,12 @@ |
__ Addu(a3, a3, Operand(FixedArray::kHeaderSize - kHeapObjectTag)); |
- // Fill fixed array elements with hole. |
+ // Fill fixed array elements with undefined. |
// v0: JSArray, tagged. |